# Security Policy

## Supported Versions

We only support the latest version of render-engine with security updates.
Please ensure you are using the most recent release available on [PyPI].

| Version  | Supported |
|----------|-----------|
| Latest   | ✅        |
| < Latest | ❌        |

## Reporting a Vulnerability

If you find a vulnerability in the latest Render Engine that is due to an external package, please [file an issue][render-engine-issues].

[PyPI]: https://pypi.org/project/render-engine/
[render-engine-issues]: https://github.com/render-engine/render-engine/issues
